/*
 *  ============LICENSE_START=======================================================
 *  Copyright (C) 2023 Nordix Foundation
 *  ================================================================================
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *  ============LICENSE_END=========================================================
 */

package org.onap.cps.ncmp.impl.inventory.trustlevel;

import io.cloudevents.CloudEvent;
import io.cloudevents.kafka.impl.KafkaHeaders;
import lombok.RequiredArgsConstructor;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.onap.cps.ncmp.api.inventory.models.TrustLevel;
import org.onap.cps.ncmp.events.trustlevel.DeviceTrustLevel;
import org.onap.cps.ncmp.utils.events.CloudEventMapper;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.stereotype.Component;

@Component
@RequiredArgsConstructor
public class DeviceTrustLevelMessageConsumer {

    private static final String CLOUD_EVENT_ID_HEADER_NAME = "ce_id";
    private final TrustLevelManager trustLevelManager;

    /**
     * Listening to the device trust level updates.
     *
     * @param consumerRecord Device trust level record.
     */
    @KafkaListener(topics = "${app.dmi.device-heartbeat.topic}",
        containerFactory = "cloudEventConcurrentKafkaListenerContainerFactory")
    public void deviceTrustLevelListener(final ConsumerRecord<String, CloudEvent> consumerRecord) {

        final String cmHandleId = KafkaHeaders.getParsedKafkaHeader(consumerRecord.headers(),
            CLOUD_EVENT_ID_HEADER_NAME);

        final DeviceTrustLevel deviceTrustLevel =
            CloudEventMapper.toTargetEvent(consumerRecord.value(), DeviceTrustLevel.class);
        final String trustLevelAsString = deviceTrustLevel.getData().getTrustLevel();
        trustLevelManager.handleUpdateOfDeviceTrustLevel(cmHandleId, TrustLevel.valueOf(trustLevelAsString));
    }

}

